import serial
import time
import thread
import os
class Xerial():

	def __init__(self, port=None, baudrate=9600, bytesize=8, parity='N', stopbits=1, timeout=None, xonxoff=0, rtscts=0, carriage=False, newline=False, log=False):
		self.ser = serial.Serial()
		self.ser.port=port 
		self.ser.baudrate=int(baudrate) 
		self.ser.bytesize=int(bytesize)
		self.ser.parity=str(parity) 
		self.ser.stopbits=float(stopbits) 
		self.ser.timeout=timeout
		self.ser.xonxoff=int(xonxoff)
		self.ser.rtscts=int(rtscts)
		self.carriage = carriage
		self.newline = newline
		if log != False:
			self.log = True
		else:
			self.log = False
		if self.log == True:
			logName = str(self.ser.port.split('/')[len(self.ser.port.split('/'))-1])+'='+str(time.strftime("%m:%d:%Y")) +'-'+ str(time.strftime("%I:%M:%S"))
			self.logFile = open(logName+".txt", 'w')


	def connect(self):
		try:
			self.ser.open()
		except:
			print 'Could not connect to ' + str(port)
			exit()
		if not self.ser.is_open:
			print 'Could not connect to ' + str(port)
			exit()
			

	def terminal(self):
		if self.ser.is_open:
			print 'Connected!'
			print "Use '>q' to exit..."
			print

		inputBuffer = ''

		thread.start_new_thread(self.listen, ())

		while inputBuffer != '>q':
			
			inputBuffer = raw_input()
			self.logFile.write(inputBuffer+'\n')

			if inputBuffer == '>q':
				self.ser.close()
				return
			self.write(inputBuffer)

		ser.close()

		return

	def write(self, inputBuffer):
		self.ser.write(inputBuffer)
		if self.carriage:
			self.ser.write('\r')
		if self.newline:
			self.ser.write('\n')

	def listen(self):
		while True:
			try:
				line = self.ser.readline().strip('\n')
				print line
				if self.log == True:
					logFile.write(line)

			except:
				return




#!/usr/bin/python 
import sys
import pkg_resources
pkg_resources.require("pyserial==3.0.1")
import glob
import json
import os
from xerial import Xerial
path = os.path.dirname(os.path.realpath(__file__))

def flags(flag):
	if flag in sys.argv:
		try:
			return sys.argv[sys.argv.index(flag)+1]
		except:
			return False

def showHelp():
	print open(path+'/docs/README.md','r').read()
	print '  Logs can be found in ' + path + "/logs/"		
	print
	print 'Available Ports:'
	print '----------------'		

	for each in glob.glob('/dev/tty.*'):
		print "  > " + str(each)

if __name__ == "xerial.xerial" or "__main__":
	if len(sys.argv) == 1:
		showHelp()
		exit()

	if '-h' in sys.argv:
		showHelp()
		exit()

	if '-ls' in sys.argv:
		ports = glob.glob('/dev/tty.*')
		if len(ports) > 0:
			for port in ports:
				print port
			exit()
		else:
			print 'No ports found...'
			exit()

	if '-lp' in sys.argv:
		if len(sys.argv) > 2:
			try:
				if not os.path.isdir(path+"/presets"):
					os.makedirs(path+"/presets")
				pf = json.load(open(path+"/presets/"+sys.argv[sys.argv.index('-lp')+1]+".xer"))
			except:
				print 'Could not load ' + sys.argv[sys.argv.index('-lp')+1]
				exit()

			
			print 'Parameters:'
			print '-----------'
			for key in pf:
				print str(key) + ':' + str(pf[key])
			print ''
			exit()

		presets = glob.glob(path+'/presets/*.xer')

		if len(presets) > 0:
			print 'Presets:'
			for preset in presets:
				print '  > '+ str(preset.split('/')[len(preset.split('/'))-1])[:-4]
			exit()
		print 'No presets found.'
		exit()

	if flags("-p") != False:
		#port = sys.argv[sys.argv.index('-c')+1]
		port = flags("-p")

		if '-b' in sys.argv:
			speed = sys.argv[sys.argv.index('-b')+1]
			try:
				speed = int(speed)
			except:
				print '  Please enter a valid baudrate. Usage: -b <baudrate>'
				exit()
		else:
			speed = '9600'

		if '-a' in sys.argv:
			try:
				args = sys.argv[sys.argv.index('-a')+1].split('/')
				if len(args) != 3:
					print '  Invalid arugment format. Usage: -a <int:bytesize>/<str:parity>/<int:stopbits>. Must include all three.'
					exit()

				bytesize = int(args[0])
				if bytesize not in range(4,9):
					print '  Invalid bytesize.  Valid sizes: "5, 6, 7, 8"'
					exit()

				parity = str(args[1])
				validParity = ['N','O','E','M','S']
				if parity not in validParity:
					print '  Invalid parity bit type. Valid types: "N, O, E, M, S"'
					exit()

				validStopbits = [1,1.5,2]
				stopbits = float(args[2])
				if stopbits not in validStopbits:
					print '  Invalid stopbit.  Valid bits: "1, 1.5, 2"'
					exit()

			except:
				print '  Invalid arugment format. Usage: -a <int:bytesize>/<str:parity>/<int:stopbits>. Must include all three.'
				exit()

		else:
			bytesize = 8
			parity = 'N'
			stopbits = 1

		if '-t' in sys.argv:
			try:
				timeout = int(sys.argv[sys.argv.index('-t')+1])
			except:
				print '  Invalid timeout time.  Usage: -t <sec>'
				exit()
		else:
			timeout = None

		if '-hw' in sys.argv:
			handshake = 1
		else:
			handshake = 0

		if '-CR' in sys.argv:
			carriage = True
		else:
			carriage = False

		if '-LF' in sys.argv:
			newline = True
		else:
			newline = False

		if  sys.argv[len(sys.argv)-2] == '-s':
			data = {
			"port":port,
			"speed":speed,
			"bytesize":bytesize,
			"parity":parity,
			"stopbits":stopbits,
			"timeout":timeout,
			"rtscts":handshake,
			"carriage":carriage,
			"newline":newline
			}

			try:
				presetName = sys.argv[sys.argv.index('-s')+1]
				
			except:
				print 'Invalid file name.  Usage: -s <filename>'
				exit()	
			if not os.path.isdir(path+"/presets"):
				os.makedirs(path+"/presets")
			with open(path+"/presets/" + presetName+".xer", 'w') as outfile:
				json.dump(data, outfile)
			exit()

		if '-log' in sys.argv:
			log = True
		else:
			log = False
		
		

	else:
		print '  No port specified.  Usage: "xerial -c <serialport>". Run "xerial" for more options.'
		exit()

	if '-license' == sys.argv[1]:
		print
		print open(path+"/docs/LICENSE.md").read()
		print
		exit()

	if sys.argv[1] == '-l':
		try:
			if not os.path.isdir(path+"/presets"):
				os.makedirs(path+"/presets")
			presetFile = open(path+"/presets/" + sys.argv[2]+".xer", 'r')
			pf = json.load(presetFile)			

		except:
			print "Could not load " + sys.argv[2]+".xer"
			exit()

		print 'Connecting to ' + str(pf["port"]) + ' at speed ' + str(pf["speed"]) + ' - ' + str(pf["bytesize"])+'/'+str(pf["parity"])+'/'+str(pf["stopbits"]) 

		xerial = Xerial(pf["port"], pf["speed"], pf["bytesize"], pf["parity"], pf["stopbits"], pf["timeout"], rtscts=pf["rtscts"], carriage=pf["carriage"], newline=pf["newline"], log=log)
		xerial.connect()
		xerial.terminal()
		exit()

	if '-p' in sys.argv:
		print 'Connecting to ' + sys.argv[sys.argv.index('-p')+1] + ' at speed ' + str(speed) + ' - ' + str(bytesize)+'/'+str(parity)+'/'+str(stopbits) 

		xerial = Xerial(port, speed, bytesize, parity, stopbits, timeout, rtscts=handshake, carriage=carriage, newline=newline, log=log)
		xerial.connect()
		xerial.terminal()
		exit()
	else:
		print "  -p <port> must be included"
		exit()














from setuptools import setup

setup(
    name='xerial',
    version='1.0.5b1',
    author='Nicholas Petty',
    author_email='nick@ihackeverything.com',
    packages=['xerial'],
    package_data={'':['docs/*.md','LICENSE']},
    include_package_data=True,
    url='http://github.com/nickpetty/xerial',
    license='GPL licence, see LICENSE',
    description='Terminal Based Serial Client',
    long_description=open('README.rst').read(),
    install_requires=['pyserial'],
    scripts=['bin/xerial']
)



